# Changelog

## 0.0.2 (2026-02-24)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/inconvoai/inconvo-python-sdk/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([59e23bd](https://github.com/inconvoai/inconvo-python-sdk/commit/59e23bd7c3d27f754e326f173bd42e5f621242fe))
* update SDK settings ([fe2f683](https://github.com/inconvoai/inconvo-python-sdk/commit/fe2f6835bbd60e0ca801060134088c6b05b8d091))
* update SDK settings ([653b243](https://github.com/inconvoai/inconvo-python-sdk/commit/653b243905b8458008f22ea61ec83fff094d15e0))
* update SDK settings ([cb55866](https://github.com/inconvoai/inconvo-python-sdk/commit/cb55866644c26dfd1836a706354e8f9e15f1b470))
